@@ -36,8 +36,7 @@ test_utf8_character (const char *utf8_char,
 {
 	GDateTime  *datetime;
 	GnomeWallClock *clock;
-	locale_t locale;
-	locale_t save_locale;
+	const char *save_locale;
 	const char *str;
 
 	/* When testing that UTF8 locales don't use double spaces
@@ -45,11 +44,12 @@ test_utf8_character (const char *utf8_char,
 	   doesn't contain double spaces ("Aug  1") */
 	datetime = g_date_time_new_local (2014, 5, 28, 23, 59, 59);
 
+	/* Save current locale */
+	save_locale = setlocale (LC_ALL, NULL);
+
 	/* In the C locale, make sure the time string is formatted with regular
          * colons */
-	locale = newlocale (LC_ALL_MASK, "C", (locale_t) 0);
-	g_assert_true (locale != (locale_t)0);
-	save_locale = uselocale (locale);
+	setlocale (LC_ALL, "C");
 	clock = gnome_wall_clock_new ();
 	str = gnome_wall_clock_string_for_datetime (clock,
 	                                            datetime,
@@ -59,14 +59,8 @@ test_utf8_character (const char *utf8_char,
 	g_assert (strstr (str, utf8_char) == NULL);
 	g_object_unref (clock);
 
-	/* In a UTF8 locale, we want ratio characters and no colons. */
-	locale = newlocale (LC_ALL_MASK, "en_US.utf8", locale);
-	if (locale == (locale_t)0) {
-		g_test_message ("en_US.utf8 locale not found");
-		g_test_fail ();
-		return;
-	}
-	uselocale (locale);
+	/* In a UTF8 locale, we want ratio characters and no colons */
+	setlocale (LC_ALL, "en_US.utf8");
 	clock = gnome_wall_clock_new ();
 	str = gnome_wall_clock_string_for_datetime (clock,
 	                                            datetime,
@@ -78,13 +72,7 @@ test_utf8_character (const char *utf8_char,
 
 	/* ... and same thing with an RTL locale: should be formatted with
          * ratio characters */
-	locale = newlocale (LC_ALL_MASK, "he_IL.utf8", locale);
-	if (locale == (locale_t)0) {
-		g_test_message ("he_IL.utf8 locale not found");
-		g_test_fail ();
-		return;
-	}
-	uselocale (locale);
+	setlocale (LC_ALL, "he_IL.utf8");
 	clock = gnome_wall_clock_new ();
 	str = gnome_wall_clock_string_for_datetime (clock,
 	                                            datetime,
@@ -97,8 +85,7 @@ test_utf8_character (const char *utf8_char,
 	g_date_time_unref (datetime);
 
 	/* Restore previous locale */
-	uselocale (save_locale);
-	freelocale (locale);
+	setlocale (LC_ALL, save_locale);
 }
 
 static void
@@ -118,18 +105,13 @@ test_clock_format_setting (void)
 {
 	GnomeWallClock *clock;
 	GSettings *settings;
-	locale_t locale;
-	locale_t save_locale;
+	const char *save_locale;
 	const char *str;
 
-	locale = newlocale (LC_ALL_MASK, "en_US.utf8", (locale_t) 0);
-	if (locale == (locale_t)0) {
-		g_test_message ("en_US.utf8 locale not found");
-		g_test_fail ();
-		return;
-	}
-	save_locale = uselocale (locale);
+	/* Save current locale */
+	save_locale = setlocale (LC_ALL, NULL);
 
+	setlocale (LC_ALL, "en_US.utf8");
 	settings = g_settings_new ("org.gnome.desktop.interface");
 
 	/* In 12h format, the string ends with AM or PM */
@@ -149,8 +131,7 @@ test_clock_format_setting (void)
 	g_object_unref (settings);
 
 	/* Restore previous locale */
-	uselocale (save_locale);
-	freelocale (locale);
+	setlocale (LC_ALL, save_locale);
 }
 
 static gboolean
@@ -202,21 +183,19 @@ test_weekday_setting (void)
 {
 	GnomeWallClock *clock;
 	GSettings *settings;
-	locale_t locale;
-	locale_t save_locale;
+	const char *save_locale;
 	const char *str, *ptr, *s;
 
 	/* Save current locale */
-	locale = newlocale (LC_ALL_MASK, "C", (locale_t) 0);
-	g_assert_true (locale != (locale_t)0);
-	save_locale = uselocale (locale);
+	save_locale = setlocale (LC_ALL, NULL);
+
+	setlocale (LC_ALL, "C");
 	settings = g_settings_new ("org.gnome.desktop.interface");
 
 	/* Set 24h format, so that the only alphabetical part will be the weekday */
 	g_settings_set_enum (settings, "clock-format", G_DESKTOP_CLOCK_FORMAT_24H);
 
 	g_settings_set_boolean (settings, "clock-show-weekday", FALSE);
-	g_settings_set_boolean (settings, "clock-show-date", FALSE);
 	clock = gnome_wall_clock_new ();
 	str = gnome_wall_clock_get_clock (clock);
 
@@ -245,8 +224,7 @@ test_weekday_setting (void)
 	g_object_unref (settings);
 
 	/* Restore previous locale */
-	uselocale (save_locale);
-	freelocale (locale);
+	setlocale (LC_ALL, save_locale);
 }
 
 int
